@@ -6,22 +6,41 @@ import os
 from typing import Dict, List, Optional, Union
 from uuid import UUID
 
+from ruamel.yaml.comments import CommentedMap
+
 import great_expectations.exceptions as ge_exceptions
 from great_expectations.checkpoint.configurator import SimpleCheckpointConfigurator
 from great_expectations.checkpoint.types.checkpoint_result import CheckpointResult
-from great_expectations.checkpoint.util import get_substituted_validation_dict
+from great_expectations.checkpoint.util import (
+    get_batch_request_as_dict,
+    get_substituted_validation_dict,
+    get_validations_with_batch_request_as_dict,
+    substitute_runtime_config,
+    substitute_template_config,
+)
 from great_expectations.core import RunIdentifier
 from great_expectations.core.async_executor import AsyncExecutor, AsyncResult
-from great_expectations.core.batch import BatchRequest, get_batch_request_dict
+from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 from great_expectations.core.usage_statistics.usage_statistics import (
     get_checkpoint_run_usage_statistics,
     usage_statistics_enabled_method,
 )
-from great_expectations.core.util import get_datetime_string_from_strftime_format
+from great_expectations.core.util import (
+    convert_to_json_serializable,
+    get_datetime_string_from_strftime_format,
+)
 from great_expectations.data_asset import DataAsset
-from great_expectations.data_context.types.base import CheckpointConfig
+from great_expectations.data_context.types.base import (
+    Attributes,
+    CheckpointConfig,
+    object_to_yaml_str,
+)
 from great_expectations.data_context.types.resource_identifiers import GeCloudIdentifier
 from great_expectations.data_context.util import substitute_all_config_variables
+from great_expectations.util import (
+    deep_filter_properties_iterable,
+    filter_properties_dict,
+)
 from great_expectations.validation_operators import ActionListValidationOperator
 from great_expectations.validation_operators.types.validation_operator_result import (
     ValidationOperatorResult,
@@ -58,11 +77,9 @@ class Checkpoint:
         data_context: "DataContext",  # noqa: F821
         config_version: Optional[Union[int, float]] = None,
         template_name: Optional[str] = None,
-        module_name: Optional[str] = None,
-        class_name: Optional[str] = None,
         run_name_template: Optional[str] = None,
         expectation_suite_name: Optional[str] = None,
-        batch_request: Optional[Union[BatchRequest, dict]] = None,
+        batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None,
         action_list: Optional[List[dict]] = None,
         evaluation_parameters: Optional[dict] = None,
         runtime_configuration: Optional[dict] = None,
@@ -73,7 +90,6 @@ class Checkpoint:
         ge_cloud_id: Optional[UUID] = None,
         expectation_suite_ge_cloud_id: Optional[UUID] = None,
     ):
-        self._name = name
         # Note the gross typechecking to avoid a circular import
         if "DataContext" not in str(type(data_context)):
             raise TypeError("A Checkpoint requires a valid DataContext")
@@ -82,105 +98,213 @@ class Checkpoint:
 
         self._data_context = data_context
 
-        checkpoint_config: CheckpointConfig = CheckpointConfig(
-            **{
-                "name": name,
-                "config_version": config_version,
-                "template_name": template_name,
-                "module_name": module_name,
-                "class_name": class_name,
-                "run_name_template": run_name_template,
-                "expectation_suite_name": expectation_suite_name,
-                "expectation_suite_ge_cloud_id": expectation_suite_ge_cloud_id,
-                "batch_request": batch_request,
-                "action_list": action_list,
-                "evaluation_parameters": evaluation_parameters,
-                "runtime_configuration": runtime_configuration,
-                "validations": validations,
-                "profilers": profilers,
-                "ge_cloud_id": ge_cloud_id,
-                # Next two fields are for LegacyCheckpoint configuration
-                "validation_operator_name": validation_operator_name,
-                "batches": batches,
-            }
+        config_kwargs: dict = {
+            "name": name,
+            "config_version": config_version,
+            "template_name": template_name,
+            "run_name_template": run_name_template,
+            "expectation_suite_name": expectation_suite_name,
+            "expectation_suite_ge_cloud_id": expectation_suite_ge_cloud_id,
+            "batch_request": batch_request or {},
+            "action_list": action_list or [],
+            "evaluation_parameters": evaluation_parameters or {},
+            "runtime_configuration": runtime_configuration or {},
+            "profilers": profilers or [],
+            "validations": validations or [],
+            "ge_cloud_id": ge_cloud_id,
+            # Next two fields are for LegacyCheckpoint configuration
+            "validation_operator_name": validation_operator_name,
+            "batches": batches,
+        } or {}
+
+        self._config_kwargs = Attributes(config_kwargs)
+
+    # TODO: Add eval param processing using new TBD parser syntax and updated EvaluationParameterParser and
+    #  parse_evaluation_parameters function (e.g. datetime substitution or specifying relative datetimes like "most
+    #  recent"). Currently, environment variable substitution is the only processing applied to evaluation parameters,
+    #  while run_name_template also undergoes strftime datetime substitution
+    @usage_statistics_enabled_method(
+        event_name="checkpoint.run",
+        args_payload_fn=get_checkpoint_run_usage_statistics,
+    )
+    def run(
+        self,
+        template_name: Optional[str] = None,
+        run_name_template: Optional[str] = None,
+        expectation_suite_name: Optional[str] = None,
+        batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None,
+        action_list: Optional[List[dict]] = None,
+        evaluation_parameters: Optional[dict] = None,
+        runtime_configuration: Optional[dict] = None,
+        validations: Optional[List[dict]] = None,
+        profilers: Optional[List[dict]] = None,
+        run_id: Optional[Union[str, RunIdentifier]] = None,
+        run_name: Optional[str] = None,
+        run_time: Optional[Union[str, datetime.datetime]] = None,
+        result_format: Optional[Union[str, dict]] = None,
+        expectation_suite_ge_cloud_id: Optional[str] = None,
+    ) -> CheckpointResult:
+        assert not (run_id and run_name) and not (
+            run_id and run_time
+        ), "Please provide either a run_id or run_name and/or run_time."
+
+        run_time = run_time or datetime.datetime.now()
+        runtime_configuration = runtime_configuration or {}
+        result_format = result_format or runtime_configuration.get("result_format")
+
+        batch_request = get_batch_request_as_dict(batch_request=batch_request)
+        validations = get_validations_with_batch_request_as_dict(
+            validations=validations
         )
-        self._config = checkpoint_config
-        self._substituted_config = None
 
-    @property
-    def name(self) -> str:
-        return self._name
+        runtime_kwargs: dict = {
+            "template_name": template_name,
+            "run_name_template": run_name_template,
+            "expectation_suite_name": expectation_suite_name,
+            "batch_request": batch_request or {},
+            "action_list": action_list or [],
+            "evaluation_parameters": evaluation_parameters or {},
+            "runtime_configuration": runtime_configuration or {},
+            "validations": validations or [],
+            "profilers": profilers or [],
+            "expectation_suite_ge_cloud_id": expectation_suite_ge_cloud_id,
+        }
 
-    @property
-    def data_context(self):
-        return self._data_context
+        substituted_runtime_config: dict = self.get_substituted_config(
+            runtime_kwargs=runtime_kwargs
+        )
 
-    @property
-    def config(self) -> CheckpointConfig:
-        return self._config
+        run_name_template = substituted_runtime_config.get("run_name_template")
 
-    @property
-    def action_list(self) -> List[Dict]:
-        return self._config.action_list
+        batch_request = substituted_runtime_config.get("batch_request")
+        validations = substituted_runtime_config.get("validations") or []
 
-    @property
-    def ge_cloud_id(self) -> UUID:
-        return self._config.ge_cloud_id
+        if len(validations) == 0 and not batch_request:
+            raise ge_exceptions.CheckpointError(
+                f'Checkpoint "{self.name}" must contain either a batch_request or validations.'
+            )
+
+        if run_name is None and run_name_template is not None:
+            run_name = get_datetime_string_from_strftime_format(
+                format_str=run_name_template, datetime_obj=run_time
+            )
+
+        run_id = run_id or RunIdentifier(run_name=run_name, run_time=run_time)
+
+        # Use AsyncExecutor to speed up I/O bound validations by running them in parallel with multithreading (if
+        # concurrency is enabled in the data context configuration) -- please see the below arguments used to initialize
+        # AsyncExecutor and the corresponding AsyncExecutor docstring for more details on when multiple threads are
+        # used.
+        with AsyncExecutor(
+            self.data_context.concurrency, max_workers=len(validations)
+        ) as async_executor:
+            # noinspection PyUnresolvedReferences
+            async_validation_operator_results: List[
+                AsyncResult[ValidationOperatorResult]
+            ] = []
+            if len(validations) > 0:
+                for idx, validation_dict in enumerate(validations):
+                    self._run_validation(
+                        substituted_runtime_config=substituted_runtime_config,
+                        async_validation_operator_results=async_validation_operator_results,
+                        async_executor=async_executor,
+                        result_format=result_format,
+                        run_id=run_id,
+                        idx=idx,
+                        validation_dict=validation_dict,
+                    )
+            else:
+                self._run_validation(
+                    substituted_runtime_config=substituted_runtime_config,
+                    async_validation_operator_results=async_validation_operator_results,
+                    async_executor=async_executor,
+                    result_format=result_format,
+                    run_id=run_id,
+                )
+
+            run_results = {}
+            for async_validation_operator_result in async_validation_operator_results:
+                run_results.update(
+                    async_validation_operator_result.result().run_results
+                )
+
+        return CheckpointResult(
+            run_id=run_id, run_results=run_results, checkpoint_config=self.config_kwargs
+        )
 
     def get_substituted_config(
         self,
-        config: Optional[Union[CheckpointConfig, dict]] = None,
         runtime_kwargs: Optional[dict] = None,
-    ) -> CheckpointConfig:
-        runtime_kwargs = runtime_kwargs or {}
-        if config is None:
-            config = self.config
-        if isinstance(config, dict):
-            config = CheckpointConfig(**config)
+    ) -> dict:
+        if runtime_kwargs is None:
+            runtime_kwargs = {}
 
-        if any(runtime_kwargs.values()):
-            config.update(runtime_kwargs=runtime_kwargs)
+        config_kwargs: dict = copy.deepcopy(self.config_kwargs)
 
-        substituted_config: Union[CheckpointConfig, dict]
+        template_name = runtime_kwargs.get("template_name")
+        if template_name:
+            config_kwargs["template_name"] = template_name
 
-        template_name = config.template_name
-        if not template_name:
-            substituted_config = copy.deepcopy(config)
-            self._substituted_config = substituted_config
-        else:
+        substituted_runtime_config: dict = self._get_substituted_template(
+            source_config=config_kwargs
+        )
+        substituted_runtime_config = self._get_substituted_runtime_kwargs(
+            source_config=substituted_runtime_config, runtime_kwargs=runtime_kwargs
+        )
+
+        return substituted_runtime_config
+
+    def _get_substituted_template(
+        self,
+        source_config: dict,
+    ) -> dict:
+        substituted_config: dict
+
+        template_name = source_config.get("template_name")
+        if template_name:
             checkpoint: Checkpoint = self.data_context.get_checkpoint(
                 name=template_name
             )
-            template_config: CheckpointConfig = checkpoint.config
+            template_config: dict = checkpoint.config_kwargs
 
-            if template_config.config_version != config.config_version:
+            if template_config["config_version"] != source_config["config_version"]:
                 raise ge_exceptions.CheckpointError(
-                    f"Invalid template '{template_name}' (ver. {template_config.config_version}) for Checkpoint "
-                    f"'{config}' (ver. {config.config_version}. Checkpoints can only use templates with the same config_version."
+                    f"Invalid template '{template_name}' (ver. {template_config['config_version']}) for Checkpoint "
+                    f"'{source_config}' (ver. {source_config['config_version']}. Checkpoints can only use templates with the same config_version."
                 )
 
-            if template_config.template_name is not None:
-                substituted_config = self.get_substituted_config(config=template_config)
-            else:
-                substituted_config = copy.deepcopy(template_config)
-
-            # merge template with config
-            substituted_config.update(
-                other_config=config, runtime_kwargs=runtime_kwargs
+            substituted_template_config: dict = self._get_substituted_template(
+                source_config=template_config
             )
-
-            # don't replace _substituted_config if already exists
-            if self._substituted_config is None:
-                self._substituted_config = substituted_config
+            substituted_config = substitute_template_config(
+                source_config=source_config, template_config=substituted_template_config
+            )
+        else:
+            substituted_config = copy.deepcopy(source_config)
 
         if self.data_context.ge_cloud_mode:
             return substituted_config
 
         return self._substitute_config_variables(config=substituted_config)
 
-    def _substitute_config_variables(
-        self, config: CheckpointConfig
-    ) -> CheckpointConfig:
+    def _get_substituted_runtime_kwargs(
+        self,
+        source_config: dict,
+        runtime_kwargs: Optional[dict] = None,
+    ) -> dict:
+        if runtime_kwargs is None:
+            runtime_kwargs = {}
+
+        substituted_config: dict = substitute_runtime_config(
+            source_config=source_config, runtime_kwargs=runtime_kwargs
+        )
+
+        if self.data_context.ge_cloud_mode:
+            return substituted_config
+
+        return self._substitute_config_variables(config=substituted_config)
+
+    def _substitute_config_variables(self, config: dict) -> dict:
         substituted_config_variables = substitute_all_config_variables(
             self.data_context.config_variables,
             dict(os.environ),
@@ -193,15 +317,15 @@ class Checkpoint:
             **self.data_context.runtime_environment,
         }
 
-        return CheckpointConfig(
-            **substitute_all_config_variables(
-                config, substitutions, self.data_context.DOLLAR_SIGN_ESCAPE_STRING
-            )
+        return substitute_all_config_variables(
+            data=config,
+            replace_variables_dict=substitutions,
+            dollar_sign_escape_string=self.data_context.DOLLAR_SIGN_ESCAPE_STRING,
         )
 
     def _run_validation(
         self,
-        substituted_runtime_config: CheckpointConfig,
+        substituted_runtime_config: dict,
         async_validation_operator_results: List[AsyncResult],
         async_executor: AsyncExecutor,
         result_format: Optional[dict],
@@ -217,9 +341,9 @@ class Checkpoint:
                 substituted_runtime_config=substituted_runtime_config,
                 validation_dict=validation_dict,
             )
-            batch_request: BatchRequest = substituted_validation_dict.get(
-                "batch_request"
-            )
+            batch_request: Union[
+                BatchRequest, RuntimeBatchRequest
+            ] = substituted_validation_dict.get("batch_request")
             expectation_suite_name: str = substituted_validation_dict.get(
                 "expectation_suite_name"
             )
@@ -297,130 +421,19 @@ class Checkpoint:
                 f"Exception occurred while running validation[{idx}] of Checkpoint '{self.name}': {e.message}."
             )
 
-    # TODO: Add eval param processing using new TBD parser syntax and updated EvaluationParameterParser and
-    #  parse_evaluation_parameters function (e.g. datetime substitution or specifying relative datetimes like "most
-    #  recent"). Currently, environment variable substitution is the only processing applied to evaluation parameters,
-    #  while run_name_template also undergoes strftime datetime substitution
-    @usage_statistics_enabled_method(
-        event_name="checkpoint.run",
-        args_payload_fn=get_checkpoint_run_usage_statistics,
-    )
-    def run(
-        self,
-        template_name: Optional[str] = None,
-        run_name_template: Optional[str] = None,
-        expectation_suite_name: Optional[str] = None,
-        batch_request: Optional[Union[dict, BatchRequest]] = None,
-        action_list: Optional[List[dict]] = None,
-        evaluation_parameters: Optional[dict] = None,
-        runtime_configuration: Optional[dict] = None,
-        validations: Optional[List[dict]] = None,
-        profilers: Optional[List[dict]] = None,
-        run_id: Optional[Union[str, RunIdentifier]] = None,
-        run_name: Optional[str] = None,
-        run_time: Optional[Union[str, datetime.datetime]] = None,
-        result_format: Optional[Union[str, dict]] = None,
-        expectation_suite_ge_cloud_id: Optional[str] = None,
-    ) -> CheckpointResult:
-        assert not (run_id and run_name) and not (
-            run_id and run_time
-        ), "Please provide either a run_id or run_name and/or run_time."
-
-        run_time = run_time or datetime.datetime.now()
-        runtime_configuration = runtime_configuration or {}
-        result_format = result_format or runtime_configuration.get("result_format")
-
-        batch_request, validations = get_batch_request_dict(
-            batch_request=batch_request, validations=validations
-        )
-
-        runtime_kwargs: dict = {
-            "template_name": template_name,
-            "run_name_template": run_name_template,
-            "expectation_suite_name": expectation_suite_name,
-            "batch_request": batch_request,
-            "action_list": action_list,
-            "evaluation_parameters": evaluation_parameters,
-            "runtime_configuration": runtime_configuration,
-            "validations": validations,
-            "profilers": profilers,
-            "expectation_suite_ge_cloud_id": expectation_suite_ge_cloud_id,
-        }
-        substituted_runtime_config: CheckpointConfig = self.get_substituted_config(
-            runtime_kwargs=runtime_kwargs
-        )
-        run_name_template = substituted_runtime_config.run_name_template
-
-        validations = substituted_runtime_config.validations
-
-        batch_request = substituted_runtime_config.batch_request
-
-        if len(validations) == 0 and not batch_request:
-            raise ge_exceptions.CheckpointError(
-                f'Checkpoint "{self.name}" must contain either a batch_request or validations.'
-            )
-
-        if run_name is None and run_name_template is not None:
-            run_name = get_datetime_string_from_strftime_format(
-                format_str=run_name_template, datetime_obj=run_time
-            )
-
-        run_id = run_id or RunIdentifier(run_name=run_name, run_time=run_time)
-
-        # Use AsyncExecutor to speed up I/O bound validations by running them in parallel with multithreading (if
-        # concurrency is enabled in the data context configuration) -- please see the below arguments used to initialize
-        # AsyncExecutor and the corresponding AsyncExecutor docstring for more details on when multiple threads are
-        # used.
-        with AsyncExecutor(
-            self.data_context.concurrency, max_workers=len(validations)
-        ) as async_executor:
-            # noinspection PyUnresolvedReferences
-            async_validation_operator_results: List[
-                AsyncResult[ValidationOperatorResult]
-            ] = []
-            if len(validations) > 0:
-                for idx, validation_dict in enumerate(validations):
-                    self._run_validation(
-                        substituted_runtime_config=substituted_runtime_config,
-                        async_validation_operator_results=async_validation_operator_results,
-                        async_executor=async_executor,
-                        result_format=result_format,
-                        run_id=run_id,
-                        idx=idx,
-                        validation_dict=validation_dict,
-                    )
-            else:
-                self._run_validation(
-                    substituted_runtime_config=substituted_runtime_config,
-                    async_validation_operator_results=async_validation_operator_results,
-                    async_executor=async_executor,
-                    result_format=result_format,
-                    run_id=run_id,
-                )
-
-            run_results = {}
-            for async_validation_operator_result in async_validation_operator_results:
-                run_results.update(
-                    async_validation_operator_result.result().run_results
-                )
-
-        return CheckpointResult(
-            run_id=run_id, run_results=run_results, checkpoint_config=self.config
-        )
-
     def self_check(self, pretty_print=True) -> dict:
         # Provide visibility into parameters that Checkpoint was instantiated with.
-        report_object: dict = {"config": self.config.to_json_dict()}
+        report_object: dict = {"config": self.config_kwargs}
 
         if pretty_print:
             print(f"\nCheckpoint class name: {self.__class__.__name__}")
 
         validations_present: bool = (
-            self.config.validations
-            and isinstance(self.config.validations, list)
-            and len(self.config.validations) > 0
+            self.validations
+            and isinstance(self.validations, list)
+            and len(self.validations) > 0
         )
-        action_list: Optional[list] = self.config.action_list
+        action_list: Optional[list] = self.action_list
         action_list_present: bool = (
             action_list is not None
             and isinstance(action_list, list)
@@ -434,7 +447,7 @@ class Checkpoint:
                         and isinstance(validation["action_list"], list)
                         and len(validation["action_list"]) > 0
                     )
-                    for validation in self.config.validations
+                    for validation in self.validations
                 ]
             )
         )
@@ -456,6 +469,83 @@ is run), with each validation having its own defined "action_list" attribute.
 
         return report_object
 
+    # noinspection PyShadowingBuiltins
+    def get_config(
+        self,
+        reconcile: bool = False,
+        runtime_kwargs: Optional[dict] = None,
+        format: str = "dict",
+        clean_falsy: bool = False,
+    ) -> Union[dict, str]:
+        if reconcile or runtime_kwargs:
+            config_kwargs: dict = self.get_substituted_config(
+                runtime_kwargs=runtime_kwargs
+            )
+        else:
+            config_kwargs = copy.deepcopy(self.config_kwargs)
+
+        if clean_falsy:
+            filter_properties_dict(
+                properties=config_kwargs,
+                clean_falsy=True,
+                keep_falsy_numerics=True,
+                inplace=True,
+            )
+
+        if format == "dict":
+            return config_kwargs
+
+        if format in ["str", "dir", "repr"]:
+            json_dict: dict = convert_to_json_serializable(data=config_kwargs)
+            deep_filter_properties_iterable(
+                properties=json_dict,
+                keep_falsy_numerics=True,
+                inplace=True,
+            )
+            return json.dumps(json_dict, indent=2)
+
+        if format == "yaml":
+            return object_to_yaml_str(obj=CommentedMap(**config_kwargs))
+
+        raise ValueError(f"Unknown format {format} in LegacyCheckpoint.get_config.")
+
+    @property
+    def config_kwargs(self) -> Attributes:
+        return self._config_kwargs
+
+    @property
+    def name(self) -> str:
+        return self.config_kwargs.name
+
+    @property
+    def config_version(self) -> float:
+        return self.config_kwargs.config_version
+
+    @property
+    def action_list(self) -> List[Dict]:
+        return self.config_kwargs.action_list
+
+    @property
+    def validations(self) -> List[Dict]:
+        return self.config_kwargs.validations
+
+    @property
+    def ge_cloud_id(self) -> UUID:
+        return self.config_kwargs.ge_cloud_id
+
+    @property
+    def data_context(self) -> "DataContext":  # noqa: F821
+        return self._data_context
+
+    def __repr__(self) -> str:
+        json_dict: dict = convert_to_json_serializable(data=self.get_config())
+        deep_filter_properties_iterable(
+            properties=json_dict,
+            keep_falsy_numerics=True,
+            inplace=True,
+        )
+        return json.dumps(json_dict, indent=2)
+
 
 class LegacyCheckpoint(Checkpoint):
     """
@@ -583,13 +673,16 @@ class LegacyCheckpoint(Checkpoint):
             batches=batches,
         )
 
-    @property
-    def validation_operator_name(self):
-        return self.config.validation_operator_name
+        self._validation_operator_name = validation_operator_name
+        self._batches = batches
 
     @property
-    def batches(self):
-        return self.config.batches
+    def validation_operator_name(self) -> Optional[str]:
+        return self._validation_operator_name
+
+    @property
+    def batches(self) -> Optional[List[dict]]:
+        return self._batches
 
     def _run_default_validation_operator(
         self,
@@ -701,16 +794,6 @@ class LegacyCheckpoint(Checkpoint):
 
         return results
 
-    def get_config(self, format="dict"):
-        if format == "dict":
-            return self.config.to_json_dict()
-
-        elif format == "yaml":
-            return self.config.to_yaml_str()
-
-        else:
-            raise ValueError(f"Unknown format {format} in LegacyCheckpoint.get_config.")
-
     def _get_batches_to_validate(self, batches):
         batches_to_validate = []
         for batch in batches:
@@ -745,11 +828,9 @@ class SimpleCheckpoint(Checkpoint):
         data_context,
         config_version: Optional[Union[int, float]] = None,
         template_name: Optional[str] = None,
-        module_name: Optional[str] = None,
-        class_name: Optional[str] = None,
         run_name_template: Optional[str] = None,
         expectation_suite_name: Optional[str] = None,
-        batch_request: Optional[Union[BatchRequest, dict]] = None,
+        batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None,
         action_list: Optional[List[dict]] = None,
         evaluation_parameters: Optional[dict] = None,
         runtime_configuration: Optional[dict] = None,
@@ -769,8 +850,6 @@ class SimpleCheckpoint(Checkpoint):
             data_context=data_context,
             config_version=config_version,
             template_name=template_name,
-            class_name=class_name,
-            module_name=module_name,
             run_name_template=run_name_template,
             expectation_suite_name=expectation_suite_name,
             batch_request=batch_request,
@@ -792,15 +871,13 @@ class SimpleCheckpoint(Checkpoint):
             data_context=data_context,
             config_version=checkpoint_config.config_version,
             template_name=checkpoint_config.template_name,
-            module_name=checkpoint_config.module_name,
-            class_name=checkpoint_config.class_name,
             run_name_template=checkpoint_config.run_name_template,
             expectation_suite_name=checkpoint_config.expectation_suite_name,
-            batch_request=checkpoint_config.batch_request,
+            batch_request=batch_request,
             action_list=checkpoint_config.action_list,
             evaluation_parameters=checkpoint_config.evaluation_parameters,
             runtime_configuration=checkpoint_config.runtime_configuration,
-            validations=checkpoint_config.validations,
+            validations=validations,
             profilers=checkpoint_config.profilers,
             ge_cloud_id=checkpoint_config.ge_cloud_id,
             expectation_suite_ge_cloud_id=checkpoint_config.expectation_suite_ge_cloud_id,
@@ -811,7 +888,7 @@ class SimpleCheckpoint(Checkpoint):
         template_name: Optional[str] = None,
         run_name_template: Optional[str] = None,
         expectation_suite_name: Optional[str] = None,
-        batch_request: Optional[Union[BatchRequest, dict]] = None,
+        batch_request: Optional[Union[BatchRequest, RuntimeBatchRequest, dict]] = None,
         action_list: Optional[List[dict]] = None,
         evaluation_parameters: Optional[dict] = None,
         runtime_configuration: Optional[dict] = None,
@@ -835,7 +912,7 @@ class SimpleCheckpoint(Checkpoint):
         # SimpleCheckpoint-specific kwargs
         if any((site_names, slack_webhook, notify_on, notify_with)):
             new_baseline_config = self._configurator_class(
-                name=self.config.name,
+                name=self.name,
                 data_context=self.data_context,
                 action_list=action_list,
                 site_names=site_names,
