@@ -10,19 +10,11 @@ from great_expectations.core.usage_statistics.util import send_usage_message
 @click.pass_context
 def store(ctx):
     """Store operations"""
-    directory: str = toolkit.parse_cli_config_file_location(
-        config_file_location=ctx.obj.config_file_location
-    ).get("directory")
-    context: DataContext = toolkit.load_data_context_with_error_handling(
-        directory=directory,
-        from_cli_upgrade_command=False,
-    )
-    # TODO consider moving this all the way up in to the CLIState constructor
-    ctx.obj.data_context = context
+    ctx.obj.data_context = ctx.obj.get_data_context_from_config_file()
 
     usage_stats_prefix = f"cli.store.{ctx.invoked_subcommand}"
     send_usage_message(
-        data_context=context,
+        data_context=ctx.obj.data_context,
         event=f"{usage_stats_prefix}.begin",
         success=True,
     )
