@@ -15,6 +15,17 @@ from great_expectations.data_context.types.base import (
     DataContextConfigDefaults,
 )
 
+"""
+NOTE (Shinnnyshinshin): This is not the UpgradeHelperV13 that is normally used by the CLI.
+
+As of 2022-01, it is only triggered by running the CLI-command:
+
+great_expectations --v2-api upgrade project
+
+on a great_expectations/ directory, and cannot be used to fully migrate a v1.0 or v2.0 configuration to a v3.0 config. A
+task for the full deprecation of this path has been placed in the backlog.
+"""
+
 
 class UpgradeHelperV13(BaseUpgradeHelper):
     def __init__(self, data_context=None, context_root_dir=None):
@@ -112,11 +123,16 @@ class UpgradeHelperV13(BaseUpgradeHelper):
     def get_upgrade_overview(self):
         upgrade_overview = f"""\
 <cyan>\
-++====================================++
-|| UpgradeHelperV13: Upgrade Overview ||
-++====================================++\
+++=====================================================++
+|| UpgradeHelperV13: Upgrade Overview (V2-API Version) ||
+++=====================================================++\
 </cyan>
 
+<red>**WARNING**</red>
+<red>You have run the 'great_expectations project upgrade' command using the --v2-api flag, which is not able to perform the full upgrade to the configuration (3.0) that is fully compatible with the V3-API</red>
+
+<red>Please re-run the 'great_expectations project upgrade' command without the --v2-api flag.</red>
+
 UpgradeHelperV13 will upgrade your project to be compatible with Great Expectations V3 API.
 """
         stores_upgrade_checklist = [
