@@ -29,14 +29,17 @@ class ActionAnonymizer(Anonymizer):
             ValidationAction,
         ]
 
-    def anonymize_action_info(self, action_name, action_obj):
-        anonymized_info_dict = {}
-        anonymized_info_dict["anonymized_name"] = self.anonymize(action_name)
+    def anonymize_action_info(self, action_name, action_obj=None, action_config=None):
+        anonymized_info_dict: dict = {
+            "anonymized_name": self.anonymize(action_name),
+        }
 
         self.anonymize_object_info(
             object_=action_obj,
+            object_config=action_config,
             anonymized_info_dict=anonymized_info_dict,
             ge_classes=self._ge_classes,
+            runtime_environment={"module_name": "great_expectations.checkpoint"},
         )
 
         return anonymized_info_dict
