@@ -53,7 +53,6 @@ from great_expectations.core.usage_statistics.schemas import (
     anonymized_usage_statistics_record_schema,
 )
 from great_expectations.core.util import nested_update
-from great_expectations.data_context.types.base import CheckpointConfig
 
 STOP_SIGNAL = object()
 
@@ -63,8 +62,8 @@ _anonymizers = {}
 
 
 class UsageStatsExceptionPrefix(enum.Enum):
-    EMIT_EXCEPTION: str = "UsageStatsException"
-    INVALID_MESSAGE: str = "UsageStatsInvalidMessage"
+    EMIT_EXCEPTION = "UsageStatsException"
+    INVALID_MESSAGE = "UsageStatsInvalidMessage"
 
 
 class UsageStatisticsHandler:
@@ -362,9 +361,9 @@ def run_validation_operator_usage_statistics(
         payload["anonymized_operator_name"] = anonymizer.anonymize(
             validation_operator_name
         )
-    except TypeError:
+    except TypeError as e:
         logger.debug(
-            "run_validation_operator_usage_statistics: Unable to create validation_operator_name hash"
+            f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, run_validation_operator_usage_statistics: Unable to create validation_operator_name hash"
         )
     if data_context._usage_statistics_handler:
         # noinspection PyBroadException
@@ -374,9 +373,9 @@ def run_validation_operator_usage_statistics(
                 batch_anonymizer.anonymize_batch_info(batch)
                 for batch in assets_to_validate
             ]
-        except Exception:
+        except Exception as e:
             logger.debug(
-                "run_validation_operator_usage_statistics: Unable to create anonymized_batches payload field"
+                f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, run_validation_operator_usage_statistics: Unable to create anonymized_batches payload field"
             )
 
     return payload
@@ -411,9 +410,9 @@ def save_expectation_suite_usage_statistics(
         payload["anonymized_expectation_suite_name"] = anonymizer.anonymize(
             expectation_suite_name
         )
-    except Exception:
+    except Exception as e:
         logger.debug(
-            "save_expectation_suite_usage_statistics: Unable to create anonymized_expectation_suite_name payload field"
+            f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, save_expectation_suite_usage_statistics: Unable to create anonymized_expectation_suite_name payload field"
         )
 
     return payload
@@ -443,9 +442,9 @@ def edit_expectation_suite_usage_statistics(
         payload["anonymized_expectation_suite_name"] = anonymizer.anonymize(
             expectation_suite_name
         )
-    except Exception:
+    except Exception as e:
         logger.debug(
-            "edit_expectation_suite_usage_statistics: Unable to create anonymized_expectation_suite_name payload field"
+            f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, edit_expectation_suite_usage_statistics: Unable to create anonymized_expectation_suite_name payload field"
         )
 
     return payload
@@ -498,9 +497,9 @@ def get_batch_list_usage_statistics(data_context, *args, **kwargs):
                 data_context._usage_statistics_handler._batch_request_anonymizer
             )
             payload = batch_request_anonymizer.anonymize_batch_request(*args, **kwargs)
-        except Exception:
+        except Exception as e:
             logger.debug(
-                "get_batch_list_usage_statistics: Unable to create anonymized_batch_request payload field"
+                f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, get_batch_list_usage_statistics: Unable to create anonymized_batch_request payload field"
             )
 
     return payload
@@ -525,23 +524,22 @@ def get_checkpoint_run_usage_statistics(checkpoint, *args, **kwargs):
                 checkpoint._usage_statistics_handler._checkpoint_run_anonymizer
             )
 
-            checkpoint_config: CheckpointConfig = copy.deepcopy(checkpoint.config)
+            checkpoint_config: dict = copy.deepcopy(checkpoint.get_config())
 
-            substituted_runtime_config: CheckpointConfig = (
+            resolved_runtime_kwargs: dict = (
                 checkpoint_run_anonymizer.resolve_config_using_acceptable_arguments(
                     *(checkpoint,), **kwargs
                 )
             )
-            resolved_runtime_kwargs: dict = substituted_runtime_config.to_json_dict()
 
             payload = checkpoint_run_anonymizer.anonymize_checkpoint_run(
                 *(checkpoint,), **resolved_runtime_kwargs
             )
 
-            checkpoint._config = checkpoint_config
-        except Exception:
+            checkpoint._config_kwargs = checkpoint_config
+        except Exception as e:
             logger.debug(
-                "get_batch_list_usage_statistics: Unable to create anonymized_checkpoint_run payload field"
+                f"{UsageStatsExceptionPrefix.EMIT_EXCEPTION.value}: {e} type: {type(e)}, get_batch_list_usage_statistics: Unable to create anonymized_checkpoint_run payload field"
             )
 
     return payload
