@@ -2,28 +2,22 @@ import logging
 import uuid
 from pathlib import Path
 from typing import Dict, Tuple
-from urllib.parse import urlparse
 
 import great_expectations.exceptions as ge_exceptions
 from great_expectations.data_context.store.store_backend import StoreBackend
-from great_expectations.util import filter_properties_dict
+from great_expectations.util import (
+    filter_properties_dict,
+    get_sqlalchemy_url,
+    import_make_url,
+)
 
 try:
     import sqlalchemy as sa
-    from sqlalchemy import (
-        Column,
-        MetaData,
-        String,
-        Table,
-        and_,
-        column,
-        create_engine,
-        select,
-        text,
-    )
-    from sqlalchemy.engine.reflection import Inspector
+    from sqlalchemy import Column, MetaData, String, Table, and_, column, select
     from sqlalchemy.engine.url import URL
     from sqlalchemy.exc import IntegrityError, NoSuchTableError, SQLAlchemyError
+
+    make_url = import_make_url()
 except ImportError:
     sa = None
     create_engine = None
@@ -80,7 +74,8 @@ class DatabaseStoreBackend(StoreBackend):
         elif connection_string is not None:
             self.engine = sa.create_engine(connection_string, **kwargs)
         elif url is not None:
-            self.drivername = urlparse(url).scheme
+            parsed_url = make_url(url)
+            self.drivername = parsed_url.drivername
             self.engine = sa.create_engine(url, **kwargs)
         else:
             raise ge_exceptions.InvalidConfigError(
@@ -179,7 +174,7 @@ class DatabaseStoreBackend(StoreBackend):
                 drivername, credentials
             )
         else:
-            options = sa.engine.url.URL(drivername, **credentials)
+            options = get_sqlalchemy_url(drivername, **credentials)
 
         self.drivername = drivername
 
@@ -232,7 +227,7 @@ class DatabaseStoreBackend(StoreBackend):
         credentials_driver_name = credentials.pop("drivername", None)
         create_engine_kwargs = {"connect_args": {"private_key": pkb}}
         return (
-            sa.engine.url.URL(drivername or credentials_driver_name, **credentials),
+            get_sqlalchemy_url(drivername or credentials_driver_name, **credentials),
             create_engine_kwargs,
         )
 
@@ -255,7 +250,7 @@ class DatabaseStoreBackend(StoreBackend):
             logger.debug("Error fetching value: " + str(e))
             raise ge_exceptions.StoreError("Unable to fetch value for key: " + str(key))
 
-    def _set(self, key, value, allow_update=True):
+    def _set(self, key, value, allow_update=True, **kwargs):
         cols = {k: v for (k, v) in zip(self.key_columns, key)}
         cols["value"] = value
 
