@@ -186,7 +186,7 @@ class MetaPandasDataset(Dataset):
                 result_format = self.default_expectation_args["result_format"]
 
             if row_condition:
-                self = self.query(row_condition).reset_index(drop=True)
+                self = self.query(row_condition)
 
             series_A = self[column_A]
             series_B = self[column_B]
@@ -297,7 +297,7 @@ class MetaPandasDataset(Dataset):
                 result_format = self.default_expectation_args["result_format"]
 
             if row_condition:
-                self = self.query(row_condition).reset_index(drop=True)
+                self = self.query(row_condition)
 
             test_df = self[column_list]
 
@@ -433,9 +433,7 @@ Notes:
                 " and must be 'python' or 'pandas'"
             )
         else:
-            return self.query(row_condition, parser=condition_parser).reset_index(
-                drop=True
-            )
+            return self.query(row_condition, parser=condition_parser)
 
     def get_row_count(self):
         return self.shape[0]
