@@ -45,6 +45,10 @@ class BaseDatasource:
         self._name = name
 
         self._data_context_root_directory = data_context_root_directory
+        if execution_engine is None:
+            raise ge_exceptions.ExecutionEngineError(
+                message="No ExecutionEngine configuration provided."
+            )
 
         try:
             self._execution_engine = instantiate_class_from_config(
@@ -93,7 +97,9 @@ class BaseDatasource:
         )
         return new_batch
 
-    def get_single_batch_from_batch_request(self, batch_request: BatchRequest) -> Batch:
+    def get_single_batch_from_batch_request(
+        self, batch_request: Union[BatchRequest, RuntimeBatchRequest]
+    ) -> Batch:
         batch_list: List[Batch] = self.get_batch_list_from_batch_request(batch_request)
         if len(batch_list) != 1:
             raise ValueError(
@@ -102,14 +108,13 @@ class BaseDatasource:
         return batch_list[0]
 
     def get_batch_definition_list_from_batch_request(
-        self, batch_request: BatchRequest
+        self, batch_request: Union[BatchRequest, RuntimeBatchRequest]
     ) -> List[BatchDefinition]:
         """
         Validates batch request and utilizes the classes'
-        Data Connectors' property to get a list of batch definition given
-         a batch request
+        Data Connectors' property to get a list of batch definition given a batch request
         Args:
-            :param batch_request: A BatchRequest object used to request a batch
+            :param batch_request: A BatchRequest or RuntimeBatchRequest object used to request a batch
             :return: A list of batch definitions
         """
         self._validate_batch_request(batch_request=batch_request)
@@ -301,7 +306,7 @@ class BaseDatasource:
         return available_data_asset_names_and_types
 
     def get_available_batch_definitions(
-        self, batch_request: BatchRequest
+        self, batch_request: Union[BatchRequest, RuntimeBatchRequest]
     ) -> List[BatchDefinition]:
         self._validate_batch_request(batch_request=batch_request)
 
@@ -345,7 +350,9 @@ class BaseDatasource:
 
         return report_object
 
-    def _validate_batch_request(self, batch_request: BatchRequest):
+    def _validate_batch_request(
+        self, batch_request: Union[BatchRequest, RuntimeBatchRequest]
+    ):
         if not (
             batch_request.datasource_name is None
             or batch_request.datasource_name == self.name
