@@ -21,6 +21,7 @@ class SimpleSqlalchemyDatasource(BaseDatasource):
         engine=None,  # sqlalchemy.engine.Engine
         introspection: dict = None,
         tables: dict = None,
+        **kwargs
     ):
         introspection = introspection or {}
         tables = tables or {}
@@ -33,6 +34,8 @@ class SimpleSqlalchemyDatasource(BaseDatasource):
             "engine": engine,
         }
 
+        self._execution_engine_config.update(**kwargs)
+
         super().__init__(name=name, execution_engine=self._execution_engine_config)
 
         self._data_connectors = {}
