@@ -244,11 +244,12 @@ class SqlAlchemyDatasource(LegacyDatasource):
                 self.engine = kwargs.pop("engine")
 
             else:
-                concurrency = (
-                    data_context.concurrency
-                    if data_context is not None
-                    else ConcurrencyConfig()
-                )
+                concurrency: ConcurrencyConfig
+                if data_context is None or data_context.concurrency is None:
+                    concurrency = ConcurrencyConfig()
+                else:
+                    concurrency = data_context.concurrency
+
                 concurrency.add_sqlalchemy_create_engine_parameters(kwargs)
 
                 # If a connection string or url was provided, use that.
