@@ -1,22 +1,17 @@
 # Utility methods for dealing with Dataset objects
-
 import logging
 from typing import Any, List
 
 import numpy as np
 
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 logger = logging.getLogger(__name__)
 
 try:
     import sqlalchemy
-    from sqlalchemy.engine.default import DefaultDialect
-    from sqlalchemy.sql.elements import WithinGroup
 except ImportError:
     logger.debug("Unable to load SqlAlchemy or one of its subclasses.")
-    DefaultDialect = None
-    WithinGroup = None
 
 
 def is_valid_partition_object(partition_object):
