@@ -95,6 +95,13 @@ class ExpectColumnSumToBeBetween(ColumnExpectation):
         "include_config": True,
         "catch_exceptions": False,
     }
+    args_keys = (
+        "column",
+        "min_value",
+        "max_value",
+        "strict_min",
+        "strict_max",
+    )
 
     """ A Column Map Metric Decorator for the Sum"""
 
