@@ -16,14 +16,13 @@ class ExpectColumnValueZScoresToBeLessThan(ColumnMapExpectation):
             and also for PandasExecutionEngine where the column dtype and provided type_ are unambiguous constraints
             (any dtype except 'object' or dtype of 'object' with type_ specified as 'object').
 
-            Parameters:
+            Args:
                 column (str): \
                     The column name of a numerical column.
                 threshold (number): \
                     A maximum Z-score threshold. All column Z-scores that are lower than this threshold will evaluate
                     successfully.
 
-
             Keyword Args:
                 mostly (None or a float between 0 and 1): \
                     Return `"success": True` if at least mostly fraction of values match the expectation. \
@@ -34,7 +33,6 @@ class ExpectColumnValueZScoresToBeLessThan(ColumnMapExpectation):
                     double_sided = True, threshold = 2 -> Z scores in non-inclusive interval(-2,2)
                     double_sided = False, threshold = 2 -> Z scores in non-inclusive interval (-infinity,2)
 
-
             Other Parameters:
                 result_format (str or None): \
                     Which output mode to use: `BOOLEAN_ONLY`, `BASIC`, `COMPLETE`, or `SUMMARY`.
@@ -80,6 +78,7 @@ class ExpectColumnValueZScoresToBeLessThan(ColumnMapExpectation):
         "include_config": True,
         "catch_exceptions": False,
     }
+    args_keys = ("column", "threshold")
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
         """
