@@ -83,9 +83,8 @@ class ExpectColumnValuesToBeJsonParseable(ColumnMapExpectation):
         "requirements": [],
     }
 
-    map_metric = "column_values.json_parsable"
+    map_metric = "column_values.json_parseable"
     success_keys = ("mostly",)
-
     default_kwarg_values = {
         "row_condition": None,
         "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
@@ -94,6 +93,7 @@ class ExpectColumnValuesToBeJsonParseable(ColumnMapExpectation):
         "include_config": True,
         "catch_exceptions": True,
     }
+    args_keys = ("column",)
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
         super().validate_configuration(configuration)
