@@ -81,7 +81,6 @@ class ExpectColumnValuesToMatchRegex(ColumnMapExpectation):
         "regex",
         "mostly",
     )
-
     default_kwarg_values = {
         "row_condition": None,
         "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
@@ -90,6 +89,10 @@ class ExpectColumnValuesToMatchRegex(ColumnMapExpectation):
         "include_config": True,
         "catch_exceptions": True,
     }
+    args_keys = (
+        "column",
+        "regex",
+    )
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
         super().validate_configuration(configuration)
