@@ -77,7 +77,6 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
         "regex_list",
         "mostly",
     )
-
     default_kwarg_values = {
         "row_condition": None,
         "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
@@ -86,6 +85,10 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
         "include_config": True,
         "catch_exceptions": True,
     }
+    args_keys = (
+        "column",
+        "regex_list",
+    )
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
         super().validate_configuration(configuration)
