@@ -1,4 +1,4 @@
-from typing import Any, Dict, Tuple
+from typing import Any, Dict
 
 from great_expectations.exceptions import GreatExpectationsError
 from great_expectations.execution_engine import (
@@ -17,6 +17,11 @@ from great_expectations.expectations.metrics.table_metric_provider import (
 )
 from great_expectations.expectations.metrics.util import get_sqlalchemy_column_metadata
 
+try:
+    from sqlalchemy.sql.elements import TextClause
+except ImportError:
+    TextClause = None
+
 
 class ColumnTypes(TableMetricProvider):
     metric_name = "table.column_types"
@@ -29,7 +34,7 @@ class ColumnTypes(TableMetricProvider):
         execution_engine: PandasExecutionEngine,
         metric_domain_kwargs: Dict,
         metric_value_kwargs: Dict,
-        metrics: Dict[Tuple, Any],
+        metrics: Dict[str, Any],
         runtime_configuration: Dict,
     ):
         df, _, _ = execution_engine.get_compute_domain(
@@ -46,7 +51,7 @@ class ColumnTypes(TableMetricProvider):
         execution_engine: SqlAlchemyExecutionEngine,
         metric_domain_kwargs: Dict,
         metric_value_kwargs: Dict,
-        metrics: Dict[Tuple, Any],
+        metrics: Dict[str, Any],
         runtime_configuration: Dict,
     ):
         batch_id = metric_domain_kwargs.get("batch_id")
@@ -71,7 +76,7 @@ class ColumnTypes(TableMetricProvider):
         execution_engine: SparkDFExecutionEngine,
         metric_domain_kwargs: Dict,
         metric_value_kwargs: Dict,
-        metrics: Dict[Tuple, Any],
+        metrics: Dict[str, Any],
         runtime_configuration: Dict,
     ):
         df, _, _ = execution_engine.get_compute_domain(
@@ -83,8 +88,15 @@ class ColumnTypes(TableMetricProvider):
 
 
 def _get_sqlalchemy_column_metadata(engine, batch_data: SqlAlchemyBatchData):
-    table_selectable = batch_data.source_table_name or batch_data.selectable.name
-    schema_name = batch_data.source_schema_name or batch_data.selectable.schema
+    # if a custom query was passed
+    if isinstance(batch_data.selectable, TextClause):
+        table_selectable: TextClause = batch_data.selectable
+        schema_name = None
+    else:
+        table_selectable: str = (
+            batch_data.source_table_name or batch_data.selectable.name
+        )
+        schema_name = batch_data.source_schema_name or batch_data.selectable.schema
     return get_sqlalchemy_column_metadata(
         engine=engine,
         table_selectable=table_selectable,
