@@ -3,7 +3,7 @@ from typing import List, Optional
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
 from great_expectations.rule_based_profiler.domain_builder import Domain, DomainBuilder
 from great_expectations.rule_based_profiler.parameter_builder import ParameterContainer
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
 class ColumnDomainBuilder(DomainBuilder):
